@@ -11,7 +11,7 @@ from .globals import java, all_obj_types
 
 
 def create_saspyconn(sasobjsp_host, sasobjsp_port, java=java):
-    saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
+    saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=False) # need to manually delete, to be compitable with win
     saspy_conn.write(f"""SAS_config_names=['sasconnection']
 SAS_config_options = {{'lock_down': False,
                     'verbose'  : True,
@@ -25,6 +25,7 @@ sasconnection = {{'java'      : '{java}',
             'options' : ["-fullstimer"]
             }}""")
     saspy_conn.seek(0)
+    saspy_conn.close()
     return saspy_conn
 
 
@@ -81,6 +82,12 @@ class AbstractSAS(saspy.SASsession):
             pass
         return self.submit(code=script)
 
+    def endsas(self):
+        os.unlink(self.saspy_conn.name)  # need to do it manually for win systems
+        super(AbstractSAS, self).endsas()
+
+
+
 
 def get_sas_connect(sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass, java=java):
     """
