@@ -12,4 +12,5 @@ class SASCS(AbstractSAS):
         super(SASCS, self).__init__(sasobjsp_host=sasobjsp_host,
                                     sasobjsp_port=sasobjsp_port,
                                     sasobjsp_user=user,
-                                    sasobjsp_pass=password)
+                                    sasobjsp_pass=password,
+                                    **kwargs)
